==> vips7.8_7.8.14.orig.tar.gz: vips-7.8.14/doc/html/libguide/images.pl <==
# LaTeX2HTML 99.2beta8 (1.43)
# Associate images original text with physical files.


$key = q/{figure}quote{preform{<verbatim_mark>verbatim47#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="657" HEIGHT="778" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Allocate a line buffer.
*/
i...
... -1 );
}/* Success.
*/
return( 0 );
}\end{verbatim}\end{quote}\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim71#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="491" HEIGHT="568" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Process function for average()....
...uence.
*/
*seq += total;return( 0 );
}\end{verbatim}\end{quote}\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim77#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="617" HEIGHT="683" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Invert an image.
*/
int
invert...
...n, NULL ) )
return( -1 );return( 0 );
}\end{verbatim}\end{quote}\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim72#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="566" HEIGHT="663" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Find average of image.
*/
int
...
...EMENTS( im ) * im-&gt;Ysize);return( 0 );
}\end{verbatim}\end{quote}\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim43#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="618" HEIGHT="890" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim66#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="618" HEIGHT="471" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim46#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="509" HEIGHT="605" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim70#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="535" HEIGHT="719" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim32#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="575" HEIGHT="814" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim67#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="557" HEIGHT="740" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Move area over the image in 10...
...EMENTS( im ) * im-&gt;Ysize);return( 0 );
}\end{verbatim}\end{quote}\end{figure}">|; 

$key = q/(x,y);MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="43" HEIGHT="34" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$(x,y)$">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim76#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="483" HEIGHT="642" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

1;

==> vips_7.10.10.orig.tar.gz: vips-7.10.10/doc/html/libguide/images.pl <==
# LaTeX2HTML 2002-2-1 (1.70)
# Associate images original text with physical files.


$key = q/{figure}quote{preform{<verbatim_mark>verbatim71#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="559" HEIGHT="567" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Process function for average()....
...ence.
*/
*seq += total;return( 0 );
}\end{verbatim}
\end{quote}\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim47#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="749" HEIGHT="777" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Allocate a line buffer.
*/
i...
...-1 );
}/* Success.
*/
return( 0 );
}\end{verbatim}
\end{quote}\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim72#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="644" HEIGHT="662" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Find average of image.
*/
int
...
...MENTS( im ) * im-&gt;Ysize);return( 0 );
}\end{verbatim}
\end{quote}\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim67#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="633" HEIGHT="739" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Move area over the image in 10...
...MENTS( im ) * im-&gt;Ysize);return( 0 );
}\end{verbatim}
\end{quote}\end{figure}">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim70#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="609" HEIGHT="720" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim66#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="703" HEIGHT="472" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim76#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="550" HEIGHT="643" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim32#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="655" HEIGHT="815" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim77#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="703" HEIGHT="681" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}/* Invert an image.
*/
int
invert...
..., NULL ) )
return( -1 );return( 0 );
}\end{verbatim}
\end{quote}\end{figure}">|; 

$key = q/(x,y);MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="40" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$(x,y)$">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim46#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="579" HEIGHT="606" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

$key = q/{figure}quote{preform{<verbatim_mark>verbatim43#preform{quote{{{{figure};FSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="703" HEIGHT="891" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="\begin{figure}\begin{quote}
\begin{verbatim}...">|; 

1;
